#
# spec file for package rng-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d }
Name:           rng-tools
Version:        6.16
Release:        1.4
Summary:        Support daemon for hardware random device
License:        GPL-3.0-or-later
Group:          System/Kernel
URL:            https://github.com/nhorman/rng-tools
Source:         https://github.com/nhorman/rng-tools/archive/v%{version}.tar.gz
Source2:        %{name}.service
Source3:        90-hwrng.rules
BuildRequires:  automake
BuildRequires:  libp11-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires:       opensc
Supplements:    modalias(pci:v00001022d00007443sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00001022d0000746Bsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002410sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002420sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002440sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000244Csv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002450sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002480sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000248Csv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000024C0sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000024CCsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000024D0sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000025A1sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002640sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002641sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002670sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002671sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002672sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002673sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002674sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002675sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002676sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002677sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002678sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00002679sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Asv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Bsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Csv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Dsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Esv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000267Fsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000027B8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000027B9sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000027BDsv*sd*bc*sc*i*)
Supplements:    modalias(virtio:d00000004v*)
ExclusiveArch:  aarch64 %{ix86} ia64 x86_64 %{arm} ppc64 ppc64le
%{?systemd_requires}

%description
This  daemon  feeds data from a random number generator to the kernel's
random  number  entropy  pool,  after	first checking the data to
ensure that it is properly random.

%prep
%setup -q

%build
./autogen.sh
# NIST Beacon fetches a randomness token over internet in clear text
# Try without this functionality
%configure --without-rtlsdr --without-nistbeacon --without-qrypt
%make_build

%install
%make_install
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 %{SOURCE3} %{buildroot}%{_udevrulesdir}/90-hwrng.rules
ln -sf /sbin/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
%{?udev_rules_update:%udev_rules_update}
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc NEWS README
%license COPYING
%{_bindir}/rngtest
%{_bindir}/randstat
%{_sbindir}/rngd
%{_mandir}/man?/*.*.gz
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%{_udevrulesdir}/90-hwrng.rules

%changelog
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 6.16:
  * Misc man page fixes, specifically addressing -V option
    misdocumentation
  * Improve security by allowing rngd to drop privlidges
  * Misc documentation improvements
  * Fix building with jitterentropy when configured for internal
    software clock usage
  * Fix building of power9 darn code on power systems that don't
    natively support DARN instruction
  * Fix jitterentropy long timeout failures on low power hardware
  * Fix various build time errors on non libc systems
  * Misc covscan issue fixes
* Sun Mar 27 2022 Dirk Müller <dmueller@suse.com>
- update to 6.15:
  * Adjust rngtests for better behavior in travis
  * fix use of non-posix setaffinity call to allow building on strict posix
    (musl) systems
  * Add armv6l to list of detected arches for pkcs11
  * misc fixes to allow building on libc-musl
  * fix a deadlock in jitter shutdown sequence
  * minor warning fixups (unused variables)
  * improve cpu detection code
  * improve jitter cpu monopolization on small/single cpu systems
* Mon Nov 15 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * rng-tools.service
* Wed Oct  6 2021 Dirk Müller <dmueller@suse.com>
- disable nistbeacon support
* Thu Aug 12 2021 Dirk Müller <dmueller@suse.com>
- update to 6.14:
  * Fixed a null pointer deref in nistbeacon entropy source
  * fixed some confguration tests
  * clarified some rngd behavior in the man page
  * update init code to do proper logging
  * various covscan fixes
  * fixed a memory leak in jitter entropy source
  * fixed possible NULL deref in rdrand source
  * various fixed in openssl mangling code
  * added randstat binary to build
  * minor modernizations to configure.ac
  * Support rndr instruction on arm
  * Support jitter software timer on coarse time systems
  * Merged all openssl use into a single helper library
  * Improved console output readability
* Thu Mar 18 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 6.12:
  * Fix compiler warning over log message format
  * Fix some typos in force-reseed documentation in rngd man page
  * Improve --list option so that we properly capture entropy sources
    that are available and configured on at build time, but failed
    initalization at run time (due to lack of hw, or some other error, etc)
  * Drop the use of libsysfs - we only used it to access a single file,
    and we can do so with a simple open/read/close.
    Given the lack of maintenance of libsysfs, we can save lots of
    effort by dropping this lib
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- update to 6.11:
  * Some CI/CD fixes in travis pipeline
  * Fix detection of duplicate pulses in nist source
  * Fix --with-rtlsdr option in configure
  * Clean up some debug statements that were erroneously left in place
  * Fix error in systemd unit file
  * Fix buffer overflow in rtlsdr entropy source
  * Fixed darn source rekeying
  * Fix various pipe read issues in jitter source
  * Fix listing of rtlsdr options
  * Misc Documentation fixes
  * Fix a broken FIPS 140-2 corner case test
  * Misc cleanups
  * Addd aes mangling to nist source
  * Improve nist performance with opportunistic use of CLOCK_MONOTONIC_COARSE
  * Add forced reseeding of kernel entropy pool
* Sat Sep 12 2020 Dirk Mueller <dmueller@suse.com>
-  update to 6.10:
  * Conversion of all entropy sources to use openssl instead of gcrypt, eliminating the need for the gcrypt library
  * updated nist beacon entropy source to conform to version 2 of the
  * Added rtlsdr radio entropy source
  * Fixed arm host_cpu name, fixing a build break
  * Fixed selection of default pkcs11 engine, based on target arch
  * Moved closing jitter entropy source printouts to be LOG_DEBUG
  * Typo fixes from codespell
  * Fix a build break with power darn entropy sourceaa
  * Improve interlock between main rngd thread, and jitterentropy threads during startup/shutdown to avoid deadlock/unneeded latency
  * Avoid writing to write_wakeup_threshold when no specific threshold is set (allowing for separate services to preform this task without warnings from rngd)
  * Enhance logging to more clearly indicate which entropy source is issuing a given log message
  * Daemonize earlier, thereby avoiding early thread exit, which in turn leads to additional latency on shutdown
  * Allow for immediate thread shutdown in jitter - By using sigsetjmp/siglongjmp, threads can exit, even when blocking in the jitter library
  * Fixed texrels on on rdrand_asm.S for pic compilation
  * allow use of libargp if libc lacks argp parsing
  * explicitly link against -lcrypto, fixing build in pkcs11 entropy source
  * replace pthread_yield with posix compliant sched_yield
  * bias rngd to use faster sources of entropy when available, falling back to slower sources when needed
  * Fix a shutdown delay resulting from a thread exit race
  * Fix a few minor compilation warnings
  * Fix make distcheck make target
  * Minor typo fixes/cleanups
  * Misc typo fixes
  * Fixed build break on ppc
  * Fixed bug in which getaffinity returns error on virt systems for jitterentropy
  * Fixed low watermark sizing for kernel entropy pool
  * Add a test mode, allowing entropy production rates to be measured
  * Added jitter library as an entropy source
  * Added short names to entropy sources (rather than just index numbers), for use in identifying sources to exclude/include/set options on
  * Deprecated tpm entropy source, as all modern tpm2 hardware in the kernel exports entropy via /dev/hwrng (the hwrng entropy source)
  * Deprecated use of indexs in exclude/include/option setting
  * Introduced the concept of slow entropy sources, that produce entropy at rates slow enough that would otherwise cause them to get disabled as being broken
  * Defaulted rdrand entropy source to not use aes, as it creates a significant performance increase
  * Update of jitterentropy-library version
  * Addition of -O flag to allow per-entropy-source option setting (documented in man page)
  * Misc jitterentropy bugfixes
  * Fixing of debug messages and quiet behavior
  * Enable runtime disablement of AES in rdrand entropy if no AES method is available
  * Make jitterentropy thread count/buffer sizes configurable
  * Make AES use in rdrand and darn entropy sources configurable
  * Fixes a few logic errors in the use of jitterentropy
  * Fixes a build issue in which make check fails
  * Some source typo fixes
  * Add caching to jitterentropy
  * Free some leaked memory on exit
  * limit nistbeacon random data based on freq and timestamp
  * Document nistbeacon more
  * improved exit code reporting
  * ability to suppress failure messages when not wanted
  * correction of nistbeacon fields on non 64 bit arches
  * proper exiting on SIGTERM/SIGINT when polling in update_kernel_random
  * Fixed a drng build issue based on a missing extern symbol
  * minor code formatting cleanup
  * ensure darn rng asm code is volatile to prevent getting optimized out
  * improve darn runtime hardware support check
  * man page fixes
  * fixed bug in which rngd takes control of the terminal
- drop rng-tools-check_signals.patch (obsolete)
* Sat Feb  6 2016 crrodriguez@opensuse.org
- 90-hwrng.rules: Improve udev rule, autostart rngd only
  when there are hwrng drivers available and one is actually
  bound to the device.
* Mon Oct 19 2015 dmueller@suse.com
- enable aarch64 as well
* Sat Oct 17 2015 dvaleev@suse.com
- Enable Power64 architecture. Starting with Power7+ we have in
  CPU random number generator
* Thu Sep 18 2014 ro@suse.de
- add patch: rng-tools-check_signals.patch (bnc#897335)
  check for signals in all loops to react to SIGINT/SIGTERM
* Wed Sep  3 2014 idonmez@suse.com
- Apparently --fill-watermark expects a number between 0 and 4096
  now. So we now set it to 3700 which is ~90%% of 4096.
* Mon Aug 25 2014 idonmez@suse.com
- Update to version 5
  * Support RDRAND capable systems that don't have AES-NI
  * Man page spelling fixes
  * Don't use fixed AES key for data reduction
  * Platform: Support x32. x86-64 micro-optimizations.
  * Fix RDRAND data reduction
  * Enable RDSEED instruction
- Add libgcrypt dependency needed for RDRAND
- Add back --fill-watermark=90%% to the service file
- Package NEWS file
- Spec cleanup
* Fri Aug 22 2014 crrodriguez@opensuse.org
- package is needed on %%arm (raspberry pi at least).
* Tue Jun 24 2014 crrodriguez@opensuse.org
- systemd: Do not start in containers, in that case
  entropy comes from the "host"
- systemd: Conflict with haveged, only one entropy daemon
  must be running.
* Wed Apr 30 2014 crrodriguez@opensuse.org
- Fix automagic startup with udev/systemd virtio-rng KERNEL
  name is hw_random not hwrng..
* Wed Apr 30 2014 crrodriguez@opensuse.org
- in some parallel universe --fill-watermark took a percentage
  value, not in this incarnation at least, where it takes
  an integer. just use the sane builtin default
* Fri Dec 27 2013 crrodriguez@opensuse.org
- udev does not like rules without a new line
* Sun Nov 24 2013 crrodriguez@opensuse.org
- there is no trousers-devel requirement anymore
- define _udevrulesdir only if not already defined
- run %%udev_rules_update, if defined.
* Wed Oct 23 2013 p.drouand@gmail.com
- Drop old sysvinit stuff; none of distribution targets use it anymore
- Remove redundant %%clean section
- Remove useless automake BuildRequires, CFLAGS export and autoreconf call
* Mon Sep  2 2013 crrodriguez@opensuse.org
- in a previous change I removed WantedBy=multi-user.target
  from the systemd service file because the service can get
  automatically started by udev, however there are usecases
  on which manual start is desirable, restore that.
* Wed May 15 2013 ro@suse.de
- remove option "--feed-interval=1" from init-script and
  service file, no current version of rng-tools has ever
  known this option (bnc#819764)
* Thu Apr 11 2013 crrodriguez@opensuse.org
- Just to be in the safe side, put udev rules later into
  the mix 50-hwrng.rules --> 90-hwrng.rules
* Tue Apr  9 2013 crrodriguez@opensuse.org
- 50-hwrng.rules + rng-tools.service, use activation by systemd+udev
  combo, the service will come up automatically when the kernel
  registers a /dev/hwrng device, service no longer requires
  manual intervention to work at all.
* Thu Oct  4 2012 lars@linux-schulserver.de
- update to version 4:
  * Add RDRAND instruction support
  * Add -q and -v options for quiet and verbose output
  * Add -p option for specifying PID file (text file containing daemon's PID)
  * Disable entropy source if facing continued failures, but be
    tolerant of the occasional fault.
  * Default device is now the preferred /dev/hwrng
  * Do not use TPM device for RNG access, if /dev/hwrng is present
    (TPM RNG is exported via the kernel, in newer kernels)
- require $remote_fs in init script as binaries are below /usr
* Sun Jan 29 2012 tabraham@novell.com
- Update to version 3
  * add rngteswt program
  * support TPM chip's hardware RNG (and thus, a framework for
    supporting multiple entropy sources)
  * change default hardware RNG device name to "/dev/hw_random"
* Sat Dec 31 2011 crrodriguez@opensuse.org
- Put rngd back into %%{_sbindir} /usr is mounted in the initrd now.
* Fri Dec 16 2011 crrodriguez@opensuse.org
- Support systemd.
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Aug 10 2011 crrodriguez@opensuse.org
- Work around VIA Nano xstore bug
- Add support for Linux 3.0
- Enable large file support
- Enable VIA PadLock support on x86_64
* Wed Mar  9 2011 coolo@novell.com
- prereq sysvinit services
* Mon Nov 22 2010 ro@suse.de
- change license from GPLv2+ to GPLv3+ as the tpm_engine code
  in the ubuntu patch uses that license (bnc#653119)
* Wed Nov 10 2010 ro@suse.de
- do not report init script as failed if no hardware found
  (bnc#624198)
* Wed May 19 2010 ro@suse.de
- move rngd back to /sbin and drop remotefs dependency from
  init script
* Mon May 17 2010 ro@suse.de
- do not enable by default
* Thu May 13 2010 cristian.rodriguez@opensuse.org
- use debian/ubuntu rng-tools_mt which is under active development
* Sun Apr 25 2010 crrodriguez@opensuse.org
- add Suplemments for all currently supported hwrngs
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Fri Nov  9 2007 bwalle@suse.de
- added PreReq for %%fillup_prereq
* Sun Apr  1 2007 bwalle@suse.de
- added init script that also probes hardware if the module
  cannot be probed by PCI IDs
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug 24 2004 ro@suse.de
- update to version 2
* Wed Jul 28 2004 ro@suse.de
- update to version 1.1
* Thu Aug 21 2003 ro@suse.de
- created package version 1.0
